@@ -86,7 +86,7 @@ sag_parseUpload <- function(x) {
   info <- do.call(stockInfo, info)
 
   # tidy fish data
-  fishdata <- sag_parseTable(x[names(x) == "Fish_Data"])
+  fishdata <- sag_parseTable(unname(x[names(x) == "Fish_Data"]))
   fishdata <- do.call(stockFishdata, fishdata)
 
   list(info = info, fishdata = fishdata)
@@ -140,6 +140,7 @@ sag_parseUpload <- function(x) {
 #'  info
 #'  # should have gotten a warning message
 #'
+#'  \dontrun{
 #'  # use icesVocab to list valid codes etc.
 #'  library(icesVocab)
 #'  # print the list of valid stock codes
@@ -153,7 +154,7 @@ sag_parseUpload <- function(x) {
 #'  # print the list of assessment model names in the ICES vocabulary
 #'  model.names <- getCodeList("AssessmentModelName")
 #'  model.names$Key
-#'
+#'  }
 #' @export
 
 stockInfo <- function(StockCode, AssessmentYear, ContactPerson, StockCategory,
@@ -264,6 +265,10 @@ validNames <- function(type = c("stockInfo", "stockFishdata")) {
       "BMGT_lower",
       "BMGT",
       "BMGT_upper",
+      "BMGTrange_low",
+      "BMGTrange_high",
+      "FMGTrange_low",
+      "FMGTrange_high",
       "FMGT_lower",
       "FMGT",
       "FMGT_upper",
@@ -277,6 +282,10 @@ validNames <- function(type = c("stockInfo", "stockFishdata")) {
       "Flim",
       "Fpa",
       "Fage",
+      "Flength",
+      "RecruitmentLength",
+      "CatchesLadingsUnits",
+      "ConfidenceIntervalDefinition",
       "RecruitmentAge",
       "CatchesLandingsUnits",
       "RecruitmentDescription",
@@ -339,7 +348,11 @@ checkStockInfo <- function(info) {
     loc2 <- c(loc1[-1] - 1, length(ending))
     ending <- sapply(1:length(loc1), function(i) paste(ending[loc1[i]:loc2[i]], collapse = ""))
     maybeid <- unique(unlist(sapply(ending, grep, x = maybe)))
-    errors$StockCode <- paste0("non valid stock code (",  info$StockCode,"). Did you mean on of these: ", paste(part1, maybe[maybeid], sep = ".", collapse = ", "), "?")
+    errors$StockCode <-
+      paste0("non valid stock code (",
+             info$StockCode,
+             "). Did you mean on of these: ",
+             paste(part1, maybe[maybeid], sep = ".", collapse = ", "), "?")
   }
 
 
