@@ -14,6 +14,22 @@ sag_webservice <- function(service, ...) {
 }
 
 
+sag_documentService_uri <- function(service, ...) {
+
+  # form uri of webservice
+  if (getOption("icesSAG.use_token")) {
+    uri <- sag_uri(service, ..., token = sg_pat())
+  } else {
+    uri <- sag_uri(service, ...)
+  }
+
+  # modify url
+  uri <- httr::modify_url(uri, path = paste0("download/", service, ".ashx"))
+
+  # return uri
+  uri
+}
+
 sag_uri <- function(service, ...) {
   # set up api url
   query <- list(...)
@@ -78,25 +94,37 @@ sag_parse <- function(x, type = "table", ...) {
 
   # otherwise parse x, first drop the root node
   x <- x[[1]]
-  type <- match.arg(type, c("table", "summary", "stockStatus", "graph", "upload", "WSDL"))
+  type <- match.arg(type, c("table", "summary", "graph", "upload", "WSDL"))
   switch(type,
     table = sag_parseTable(x),
     summary = sag_parseSummary(x),
-    stockStatus = sag_parseStockStatus(x),
     graph = sag_parseGraph(x),
     upload = sag_parseUpload(x),
     WSDL = sag_parseWSDL(x))
 }
 
 
+
+
 sag_parseTable <- function(x) {
   # x is a table structure
-  xrow <- structure(rep(NA, length(x[[1]])), names = names(x[[1]]))
+  # get column names
+  if (is.null(names(x[1]))) {
+    xnames <- unique(unlist(unname(lapply(x, names))))
+  } else {
+    xnames <- sag_getXmlDataType(names(x[1]))
+    returned_names <- unique(unlist(unname(lapply(x, names))))
+    xnames <- xnames[xnames %in% returned_names]
+  }
 
+  # convert to DF
   x <- lapply(unname(x), unlist)
-  # add NAs to empty columns
-  bool <- sapply(x, length) < length(xrow)
-  x[bool] <- lapply(x[bool], function(y) {out <- xrow; out[names(y)] <- y; out})
+  # expand missing entries columns
+  x <- lapply(x, function(x) {
+                   x <- x[xnames]
+                   names(x) <- xnames
+                   x
+                 })
   # rbind into a matrix
   x <- do.call(rbind, x)
 
@@ -107,8 +135,7 @@ sag_parseTable <- function(x) {
   x[] <- trimws(x)
 
   # SAG uses "" and "NA" to indicate NA
-  x[x == ""] <- NA
-  x[x == "NA"] <- NA
+  x[x %in% c("", "NA")] <- NA
 
   # make into a data.frame
   x <- as.data.frame(x, stringsAsFactors = FALSE)
@@ -120,7 +147,7 @@ sag_parseTable <- function(x) {
 
 sag_parseSummary <- function(x) {
   # get auxilliary info
-  info <- sag_parseTable(list(x[names(x) != "lines"]))
+  info <- sag_parseTable(list(SummaryTable = x[which(names(x) != "lines")]))
 
   # parse summary table
   x <- sag_parseTable(x[["lines"]])
@@ -130,21 +157,6 @@ sag_parseSummary <- function(x) {
 }
 
 
-sag_parseStockStatus <- function(x) {
-
-  x <-
-    lapply(x, function(x) {
-        cbind(
-          sag_parseTable(x[["YearStatus"]]),
-          sag_parseTable(list(x[names(x) != "YearStatus"]))
-        )
-    })
-
-  out <- do.call(rbind, x)
-  rownames(out) <- NULL
-  out
-}
-
 
 sag_parseGraph <- function(x, size = 2^16) {
   # get png file info
@@ -165,7 +177,7 @@ sag_parseWSDL <- function(x) {
   x <- x$types$schema[names(x$types$schema) == "element"]
   types <- lapply(x, function(x) attributes(x)$names)
   keep <- sapply(types, function(x) identical(x == "complexType", TRUE))
-  keep <- which(keep)[seq(1,sum(keep), by = 2)]
+  keep <- which(keep)[seq(1, sum(keep), by = 2)]
 
   # strip out only webservice calls
   x <- x[keep]
@@ -197,11 +209,11 @@ plot.ices_standardgraph_list <- function(x, y = NULL, ...) {
 
   # calculate x and y locations for plots -
   # plot like a table: from top to bottom and left to right
-  x_loc <- rep((1:r)/r - 1/(2*r), c)
-  y_loc <- rep((c:1)/c  - 1/(2*c), each = r)
+  x_loc <- rep((1:r) / r - 1 / (2 * r), c)
+  y_loc <- rep((c:1) / c  - 1 / (2 * c), each = r)
   for (i in seq_along(x)) {
     if (!is.null(x[[i]]))
-      grid::grid.raster(x[[i]], x = x_loc[i], y = y_loc[i], width = 1/r, height = 1/c)
+      grid::grid.raster(x[[i]], x = x_loc[i], y = y_loc[i], width = 1 / r, height = 1 / c)
   }
 }
 
@@ -216,32 +228,27 @@ simplify <- function(x) {
       x[[i]] <- simplify(x[[i]])
   }
   # matrix
-  else if (is.matrix(x))
-  {
+  else if (is.matrix(x)) {
     if (is.character(x) && sum(is.na(as.numeric(x))) == sum(is.na(x)))
       mode(x) <- "numeric"
-    if (is.numeric(x))
-    {
+    if (is.numeric(x)) {
       y <- as.integer(x)
       if (sum(is.na(x)) == sum(is.na(y)) && all(x == y, na.rm = TRUE))
         mode(x) <- "integer"
     }
   }
   # vector
-  else
-  {
+  else {
     if (is.factor(x))
       x <- as.character(x)
-    if (is.character(x))
-    {
-      if (!any(grepl("[a-z|A-Z|//]", x))) {
+    if (is.character(x)) {
+      if (!any(grepl("[^0-9.]", x))) {
         y <- as.numeric(x)
         if (sum(is.na(y)) == sum(is.na(x)))
           x <- y
       }
     }
-    if (is.numeric(x))
-    {
+    if (is.numeric(x)) {
       y <- as.integer(x)
       if (sum(is.na(x)) == sum(is.na(y)) && all(x == y, na.rm = TRUE))
         x <- y
@@ -249,4 +256,3 @@ simplify <- function(x) {
   }
   x
 }
-
